@@ -27,7 +27,7 @@ build_time_vars = {'ABIFLAGS': '',
  'CCSHARED': '-fPIC',
  'CFLAGS': '-fno-strict-overflow -Wsign-compare '
            '-DDYNAMIC_ANNOTATIONS_ENABLED=1 -DNDEBUG -fexceptions -fexceptions '
-           '-fexceptions',
+           '-fexceptions   -O3',
  'CFLAGSFORSHARED': '-fPIC',
  'CFLAGS_ALIASING': '',
  'CODECS_COMMON_HEADERS': '/builddir/build/BUILD/Python-3.12.4/Modules/cjkcodecs/multibytecodec.h '
@@ -36,9 +36,9 @@ build_time_vars = {'ABIFLAGS': '',
  'CONFIGFILES': 'configure configure.ac acconfig.h pyconfig.h.in '
                 'Makefile.pre.in',
  'CONFIGURE_CFLAGS': '-fexceptions',
- 'CONFIGURE_CFLAGS_NODIST': '-O2 -flto=auto -ffat-lto-objects -fexceptions -g '
+ 'CONFIGURE_CFLAGS_NODIST': '-flto=auto -ffat-lto-objects -fexceptions -g '
                             '-grecord-gcc-switches -pipe -Wall '
-                            '-Werror=format-security '
+                            '-Wno-complain-wrong-lang -Werror=format-security '
                             '-Wp,-U_FORTIFY_SOURCE,-D_FORTIFY_SOURCE=3 '
                             '-Wp,-D_GLIBCXX_ASSERTIONS '
                             '-specs=/usr/lib/rpm/redhat/redhat-hardened-cc1 '
@@ -671,9 +671,10 @@ build_time_vars = {'ABIFLAGS': '',
  'LIBEXPAT_A': 'Modules/expat/libexpat.a',
  'LIBEXPAT_CFLAGS': '-fno-strict-overflow -Wsign-compare '
                     '-DDYNAMIC_ANNOTATIONS_ENABLED=1 -DNDEBUG -fexceptions '
-                    '-fexceptions -fexceptions -O2 -flto=auto '
+                    '-fexceptions -fexceptions   -O3 -flto=auto '
                     '-ffat-lto-objects -fexceptions -g -grecord-gcc-switches '
-                    '-pipe -Wall -Werror=format-security '
+                    '-pipe -Wall -Wno-complain-wrong-lang '
+                    '-Werror=format-security '
                     '-Wp,-U_FORTIFY_SOURCE,-D_FORTIFY_SOURCE=3 '
                     '-Wp,-D_GLIBCXX_ASSERTIONS '
                     '-specs=/usr/lib/rpm/redhat/redhat-hardened-cc1 '
@@ -686,16 +687,17 @@ build_time_vars = {'ABIFLAGS': '',
                     '-Wextra -Wno-unused-parameter '
                     '-Wno-missing-field-initializers -Wstrict-prototypes '
                     '-Werror=implicit-function-declaration -fvisibility=hidden '
-                    '-O2 -flto=auto -ffat-lto-objects -fexceptions -g '
-                    '-grecord-gcc-switches -pipe -Wall -Werror=format-security '
+                    '-flto=auto -ffat-lto-objects -fexceptions -g '
+                    '-grecord-gcc-switches -pipe -Wall '
+                    '-Wno-complain-wrong-lang -Werror=format-security '
                     '-Wp,-U_FORTIFY_SOURCE,-D_FORTIFY_SOURCE=3 '
                     '-Wp,-D_GLIBCXX_ASSERTIONS '
                     '-specs=/usr/lib/rpm/redhat/redhat-hardened-cc1 '
                     '-fstack-protector-strong '
                     '-specs=/usr/lib/rpm/redhat/redhat-annobin-cc1  '
                     '-mbranch-protection=standard -fasynchronous-unwind-tables '
-                    '-fstack-clash-protection    -D_GNU_SOURCE -fPIC -fwrapv  '
-                    '-fprofile-use -fprofile-correction '
+                    '-fstack-clash-protection    -D_GNU_SOURCE -fPIC -fwrapv '
+                    '-O3 -fprofile-use -fprofile-correction '
                     '-I/builddir/build/BUILD/Python-3.12.4/Include/internal '
                     '-IObjects -IInclude -IPython -I. '
                     '-I/builddir/build/BUILD/Python-3.12.4/Include -fPIC -fPIC',
@@ -704,9 +706,10 @@ build_time_vars = {'ABIFLAGS': '',
  'LIBHACL_CFLAGS': '-I/builddir/build/BUILD/Python-3.12.4/Modules/_hacl/include '
                    '-D_BSD_SOURCE -D_DEFAULT_SOURCE -fno-strict-overflow '
                    '-Wsign-compare -DDYNAMIC_ANNOTATIONS_ENABLED=1 -DNDEBUG '
-                   '-fexceptions -fexceptions -fexceptions -O2 -flto=auto '
+                   '-fexceptions -fexceptions -fexceptions   -O3 -flto=auto '
                    '-ffat-lto-objects -fexceptions -g -grecord-gcc-switches '
-                   '-pipe -Wall -Werror=format-security '
+                   '-pipe -Wall -Wno-complain-wrong-lang '
+                   '-Werror=format-security '
                    '-Wp,-U_FORTIFY_SOURCE,-D_FORTIFY_SOURCE=3 '
                    '-Wp,-D_GLIBCXX_ASSERTIONS '
                    '-specs=/usr/lib/rpm/redhat/redhat-hardened-cc1 '
@@ -718,17 +721,17 @@ build_time_vars = {'ABIFLAGS': '',
                    '-ffat-lto-objects -flto-partition=none -g -std=c11 -Wextra '
                    '-Wno-unused-parameter -Wno-missing-field-initializers '
                    '-Wstrict-prototypes -Werror=implicit-function-declaration '
-                   '-fvisibility=hidden -O2 -flto=auto -ffat-lto-objects '
+                   '-fvisibility=hidden -flto=auto -ffat-lto-objects '
                    '-fexceptions -g -grecord-gcc-switches -pipe -Wall '
-                   '-Werror=format-security '
+                   '-Wno-complain-wrong-lang -Werror=format-security '
                    '-Wp,-U_FORTIFY_SOURCE,-D_FORTIFY_SOURCE=3 '
                    '-Wp,-D_GLIBCXX_ASSERTIONS '
                    '-specs=/usr/lib/rpm/redhat/redhat-hardened-cc1 '
                    '-fstack-protector-strong '
                    '-specs=/usr/lib/rpm/redhat/redhat-annobin-cc1  '
                    '-mbranch-protection=standard -fasynchronous-unwind-tables '
-                   '-fstack-clash-protection    -D_GNU_SOURCE -fPIC -fwrapv  '
-                   '-fprofile-use -fprofile-correction '
+                   '-fstack-clash-protection    -D_GNU_SOURCE -fPIC -fwrapv '
+                   '-O3 -fprofile-use -fprofile-correction '
                    '-I/builddir/build/BUILD/Python-3.12.4/Include/internal '
                    '-IObjects -IInclude -IPython -I. '
                    '-I/builddir/build/BUILD/Python-3.12.4/Include -fPIC -fPIC',
@@ -741,9 +744,10 @@ build_time_vars = {'ABIFLAGS': '',
  'LIBMPDEC_CFLAGS': '-DCONFIG_64=1 -DANSI=1 -DHAVE_UINT128_T=1 '
                     '-fno-strict-overflow -Wsign-compare '
                     '-DDYNAMIC_ANNOTATIONS_ENABLED=1 -DNDEBUG -fexceptions '
-                    '-fexceptions -fexceptions -O2 -flto=auto '
+                    '-fexceptions -fexceptions   -O3 -flto=auto '
                     '-ffat-lto-objects -fexceptions -g -grecord-gcc-switches '
-                    '-pipe -Wall -Werror=format-security '
+                    '-pipe -Wall -Wno-complain-wrong-lang '
+                    '-Werror=format-security '
                     '-Wp,-U_FORTIFY_SOURCE,-D_FORTIFY_SOURCE=3 '
                     '-Wp,-D_GLIBCXX_ASSERTIONS '
                     '-specs=/usr/lib/rpm/redhat/redhat-hardened-cc1 '
@@ -756,16 +760,17 @@ build_time_vars = {'ABIFLAGS': '',
                     '-Wextra -Wno-unused-parameter '
                     '-Wno-missing-field-initializers -Wstrict-prototypes '
                     '-Werror=implicit-function-declaration -fvisibility=hidden '
-                    '-O2 -flto=auto -ffat-lto-objects -fexceptions -g '
-                    '-grecord-gcc-switches -pipe -Wall -Werror=format-security '
+                    '-flto=auto -ffat-lto-objects -fexceptions -g '
+                    '-grecord-gcc-switches -pipe -Wall '
+                    '-Wno-complain-wrong-lang -Werror=format-security '
                     '-Wp,-U_FORTIFY_SOURCE,-D_FORTIFY_SOURCE=3 '
                     '-Wp,-D_GLIBCXX_ASSERTIONS '
                     '-specs=/usr/lib/rpm/redhat/redhat-hardened-cc1 '
                     '-fstack-protector-strong '
                     '-specs=/usr/lib/rpm/redhat/redhat-annobin-cc1  '
                     '-mbranch-protection=standard -fasynchronous-unwind-tables '
-                    '-fstack-clash-protection    -D_GNU_SOURCE -fPIC -fwrapv  '
-                    '-fprofile-use -fprofile-correction '
+                    '-fstack-clash-protection    -D_GNU_SOURCE -fPIC -fwrapv '
+                    '-O3 -fprofile-use -fprofile-correction '
                     '-I/builddir/build/BUILD/Python-3.12.4/Include/internal '
                     '-IObjects -IInclude -IPython -I. '
                     '-I/builddir/build/BUILD/Python-3.12.4/Include -fPIC -fPIC',
@@ -1135,10 +1140,10 @@ build_time_vars = {'ABIFLAGS': '',
  'PY_BUILTIN_HASHLIB_HASHES': '"blake2"',
  'PY_BUILTIN_MODULE_CFLAGS': '-fno-strict-overflow -Wsign-compare '
                              '-DDYNAMIC_ANNOTATIONS_ENABLED=1 -DNDEBUG '
-                             '-fexceptions -fexceptions -fexceptions -O2 '
+                             '-fexceptions -fexceptions -fexceptions   -O3 '
                              '-flto=auto -ffat-lto-objects -fexceptions -g '
                              '-grecord-gcc-switches -pipe -Wall '
-                             '-Werror=format-security '
+                             '-Wno-complain-wrong-lang -Werror=format-security '
                              '-Wp,-U_FORTIFY_SOURCE,-D_FORTIFY_SOURCE=3 '
                              '-Wp,-D_GLIBCXX_ASSERTIONS '
                              '-specs=/usr/lib/rpm/redhat/redhat-hardened-cc1 '
@@ -1154,9 +1159,9 @@ build_time_vars = {'ABIFLAGS': '',
                              '-Wno-missing-field-initializers '
                              '-Wstrict-prototypes '
                              '-Werror=implicit-function-declaration '
-                             '-fvisibility=hidden -O2 -flto=auto '
-                             '-ffat-lto-objects -fexceptions -g '
-                             '-grecord-gcc-switches -pipe -Wall '
+                             '-fvisibility=hidden -flto=auto -ffat-lto-objects '
+                             '-fexceptions -g -grecord-gcc-switches -pipe '
+                             '-Wall -Wno-complain-wrong-lang '
                              '-Werror=format-security '
                              '-Wp,-U_FORTIFY_SOURCE,-D_FORTIFY_SOURCE=3 '
                              '-Wp,-D_GLIBCXX_ASSERTIONS '
@@ -1166,17 +1171,17 @@ build_time_vars = {'ABIFLAGS': '',
                              '-mbranch-protection=standard '
                              '-fasynchronous-unwind-tables '
                              '-fstack-clash-protection    -D_GNU_SOURCE -fPIC '
-                             '-fwrapv  -fprofile-use -fprofile-correction '
+                             '-fwrapv -O3 -fprofile-use -fprofile-correction '
                              '-I/builddir/build/BUILD/Python-3.12.4/Include/internal '
                              '-IObjects -IInclude -IPython -I. '
                              '-I/builddir/build/BUILD/Python-3.12.4/Include '
                              '-fPIC -DPy_BUILD_CORE_BUILTIN',
  'PY_CFLAGS': '-fno-strict-overflow -Wsign-compare '
               '-DDYNAMIC_ANNOTATIONS_ENABLED=1 -DNDEBUG -fexceptions '
-              '-fexceptions -fexceptions',
- 'PY_CFLAGS_NODIST': '-O2 -flto=auto -ffat-lto-objects -fexceptions -g '
+              '-fexceptions -fexceptions   -O3',
+ 'PY_CFLAGS_NODIST': '-flto=auto -ffat-lto-objects -fexceptions -g '
                      '-grecord-gcc-switches -pipe -Wall '
-                     '-Werror=format-security '
+                     '-Wno-complain-wrong-lang -Werror=format-security '
                      '-Wp,-U_FORTIFY_SOURCE,-D_FORTIFY_SOURCE=3 '
                      '-Wp,-D_GLIBCXX_ASSERTIONS '
                      '-specs=/usr/lib/rpm/redhat/redhat-hardened-cc1 '
@@ -1190,9 +1195,9 @@ build_time_vars = {'ABIFLAGS': '',
                      '-Wno-unused-parameter -Wno-missing-field-initializers '
                      '-Wstrict-prototypes '
                      '-Werror=implicit-function-declaration '
-                     '-fvisibility=hidden -O2 -flto=auto -ffat-lto-objects '
+                     '-fvisibility=hidden -flto=auto -ffat-lto-objects '
                      '-fexceptions -g -grecord-gcc-switches -pipe -Wall '
-                     '-Werror=format-security '
+                     '-Wno-complain-wrong-lang -Werror=format-security '
                      '-Wp,-U_FORTIFY_SOURCE,-D_FORTIFY_SOURCE=3 '
                      '-Wp,-D_GLIBCXX_ASSERTIONS '
                      '-specs=/usr/lib/rpm/redhat/redhat-hardened-cc1 '
@@ -1200,14 +1205,15 @@ build_time_vars = {'ABIFLAGS': '',
                      '-specs=/usr/lib/rpm/redhat/redhat-annobin-cc1  '
                      '-mbranch-protection=standard '
                      '-fasynchronous-unwind-tables -fstack-clash-protection    '
-                     '-D_GNU_SOURCE -fPIC -fwrapv  -fprofile-use '
+                     '-D_GNU_SOURCE -fPIC -fwrapv -O3 -fprofile-use '
                      '-fprofile-correction '
                      '-I/builddir/build/BUILD/Python-3.12.4/Include/internal',
  'PY_COERCE_C_LOCALE': 1,
  'PY_CORE_CFLAGS': '-fno-strict-overflow -Wsign-compare '
                    '-DDYNAMIC_ANNOTATIONS_ENABLED=1 -DNDEBUG -fexceptions '
-                   '-fexceptions -fexceptions -O2 -flto=auto -ffat-lto-objects '
-                   '-fexceptions -g -grecord-gcc-switches -pipe -Wall '
+                   '-fexceptions -fexceptions   -O3 -flto=auto '
+                   '-ffat-lto-objects -fexceptions -g -grecord-gcc-switches '
+                   '-pipe -Wall -Wno-complain-wrong-lang '
                    '-Werror=format-security '
                    '-Wp,-U_FORTIFY_SOURCE,-D_FORTIFY_SOURCE=3 '
                    '-Wp,-D_GLIBCXX_ASSERTIONS '
@@ -1220,17 +1226,17 @@ build_time_vars = {'ABIFLAGS': '',
                    '-ffat-lto-objects -flto-partition=none -g -std=c11 -Wextra '
                    '-Wno-unused-parameter -Wno-missing-field-initializers '
                    '-Wstrict-prototypes -Werror=implicit-function-declaration '
-                   '-fvisibility=hidden -O2 -flto=auto -ffat-lto-objects '
+                   '-fvisibility=hidden -flto=auto -ffat-lto-objects '
                    '-fexceptions -g -grecord-gcc-switches -pipe -Wall '
-                   '-Werror=format-security '
+                   '-Wno-complain-wrong-lang -Werror=format-security '
                    '-Wp,-U_FORTIFY_SOURCE,-D_FORTIFY_SOURCE=3 '
                    '-Wp,-D_GLIBCXX_ASSERTIONS '
                    '-specs=/usr/lib/rpm/redhat/redhat-hardened-cc1 '
                    '-fstack-protector-strong '
                    '-specs=/usr/lib/rpm/redhat/redhat-annobin-cc1  '
                    '-mbranch-protection=standard -fasynchronous-unwind-tables '
-                   '-fstack-clash-protection    -D_GNU_SOURCE -fPIC -fwrapv  '
-                   '-fprofile-use -fprofile-correction '
+                   '-fstack-clash-protection    -D_GNU_SOURCE -fPIC -fwrapv '
+                   '-O3 -fprofile-use -fprofile-correction '
                    '-I/builddir/build/BUILD/Python-3.12.4/Include/internal '
                    '-IObjects -IInclude -IPython -I. '
                    '-I/builddir/build/BUILD/Python-3.12.4/Include -fPIC '
@@ -1277,10 +1283,10 @@ build_time_vars = {'ABIFLAGS': '',
  'PY_SSL_DEFAULT_CIPHER_STRING': 0,
  'PY_STDMODULE_CFLAGS': '-fno-strict-overflow -Wsign-compare '
                         '-DDYNAMIC_ANNOTATIONS_ENABLED=1 -DNDEBUG -fexceptions '
-                        '-fexceptions -fexceptions -O2 -flto=auto '
+                        '-fexceptions -fexceptions   -O3 -flto=auto '
                         '-ffat-lto-objects -fexceptions -g '
                         '-grecord-gcc-switches -pipe -Wall '
-                        '-Werror=format-security '
+                        '-Wno-complain-wrong-lang -Werror=format-security '
                         '-Wp,-U_FORTIFY_SOURCE,-D_FORTIFY_SOURCE=3 '
                         '-Wp,-D_GLIBCXX_ASSERTIONS '
                         '-specs=/usr/lib/rpm/redhat/redhat-hardened-cc1 '
@@ -1295,9 +1301,9 @@ build_time_vars = {'ABIFLAGS': '',
                         '-Wno-unused-parameter -Wno-missing-field-initializers '
                         '-Wstrict-prototypes '
                         '-Werror=implicit-function-declaration '
-                        '-fvisibility=hidden -O2 -flto=auto -ffat-lto-objects '
+                        '-fvisibility=hidden -flto=auto -ffat-lto-objects '
                         '-fexceptions -g -grecord-gcc-switches -pipe -Wall '
-                        '-Werror=format-security '
+                        '-Wno-complain-wrong-lang -Werror=format-security '
                         '-Wp,-U_FORTIFY_SOURCE,-D_FORTIFY_SOURCE=3 '
                         '-Wp,-D_GLIBCXX_ASSERTIONS '
                         '-specs=/usr/lib/rpm/redhat/redhat-hardened-cc1 '
@@ -1306,7 +1312,7 @@ build_time_vars = {'ABIFLAGS': '',
                         '-mbranch-protection=standard '
                         '-fasynchronous-unwind-tables '
                         '-fstack-clash-protection    -D_GNU_SOURCE -fPIC '
-                        '-fwrapv  -fprofile-use -fprofile-correction '
+                        '-fwrapv -O3 -fprofile-use -fprofile-correction '
                         '-I/builddir/build/BUILD/Python-3.12.4/Include/internal '
                         '-IObjects -IInclude -IPython -I. '
                         '-I/builddir/build/BUILD/Python-3.12.4/Include -fPIC',
